@@ -45,12 +45,19 @@ def resources(**options):
     type = options.pop("type", None)
     uri = ["resources", resource_type]
     if type: uri.append(type)
-    return call_api("get", uri, only(options, "next_cursor", "max_results", "prefix"), **options)
+    return call_api("get", uri, only(options, "next_cursor", "max_results", "prefix", "tags", "context"), **options)
 
 def resources_by_tag(tag, **options):
     resource_type = options.pop("resource_type", "image")
     uri = ["resources", resource_type, "tags", tag]
-    return call_api("get", uri, only(options, "next_cursor", "max_results"), **options)
+    return call_api("get", uri, only(options, "next_cursor", "max_results", "tags", "context"), **options)
+
+def resources_by_ids(public_ids, **options):
+    resource_type = options.pop("resource_type", "image")
+    type = options.pop("type", "upload")
+    uri = ["resources", resource_type, type]
+    params = [("public_ids[]", public_id) for public_id in public_ids]
+    return call_api("get", uri, params + only(options, "tags", "context").items(), **options)
 
 def resource(public_id, **options):
     resource_type = options.pop("resource_type", "image")
@@ -63,13 +70,20 @@ def delete_resources(public_ids, **options):
     type = options.pop("type", "upload")
     uri = ["resources", resource_type, type]
     params = [("public_ids[]", public_id) for public_id in public_ids]
-    return call_api("delete", uri, params + only(options, "keep_original").items(), **options)
+    return call_api("delete", uri, params + only(options, "keep_original", "next_cursor").items(), **options)
 
 def delete_resources_by_prefix(prefix, **options):
     resource_type = options.pop("resource_type", "image")
     type = options.pop("type", "upload")
     uri = ["resources", resource_type, type]
-    return call_api("delete", uri, dict(only(options, "keep_original"), prefix=prefix), **options)
+    return call_api("delete", uri, dict(only(options, "keep_original", "next_cursor"), prefix=prefix), **options)
+
+def delete_all_resources(**options):
+    resource_type = options.pop("resource_type", "image")
+    type = options.pop("type", "upload")
+    uri = ["resources", resource_type, type]
+    return call_api("delete", uri, dict(only(options, "keep_original", "next_cursor"), all=True), **options)
+
 
 def delete_resources_by_tag(tag, **options):
     resource_type = options.pop("resource_type", "image")
@@ -128,6 +142,7 @@ def call_api(method, uri, params, **options):
     # Add authentication
     base64string = base64.encodestring('%s:%s' % (api_key, api_secret)).replace('\n', '')
     request.add_header("Authorization", "Basic %s" % base64string)
+    request.add_header("User-Agent", cloudinary.USER_AGENT)
     request.get_method = lambda: method.upper()
 
     try:
