@@ -1,6 +1,7 @@
 # Copyright Cloudinary
 import cloudinary
 from cloudinary import utils
+from cloudinary.api import Error
 import json
 import re
 from poster.encode import multipart_encode
@@ -52,7 +53,11 @@ def build_upload_params(**options):
               "eager_async": options.get("eager_async"),
               "proxy": options.get("proxy"),
               "folder": options.get("folder"),
-              "tags": options.get("tags") and ",".join(utils.build_array(options["tags"]))}
+              "overwrite": options.get("overwrite"),
+              "tags": options.get("tags") and ",".join(utils.build_array(options["tags"])),
+              "allowed_formats": options.get("allowed_formats") and ",".join(utils.build_array(options["allowed_formats"])),
+              "face_coordinates": utils.encode_double_array(options.get("face_coordinates")),
+              "context": utils.encode_dict(options.get("context"))}
     params = dict( [ (k, __safe_value(v)) for (k,v) in params.items()] )
     return params
 
@@ -101,7 +106,8 @@ def explicit(public_id, **options):
         "callback": options.get("callback"),
         "headers": build_custom_headers(options.get("headers")),
         "eager": build_eager(options.get("eager")),
-        "tags": options.get("tags") and ",".join(utils.build_array(options["tags"]))}
+        "tags": options.get("tags") and ",".join(utils.build_array(options["tags"])),
+        "face_coordinates": utils.encode_double_array(options.get("face_coordinates"))}
      return call_api("explicit", params, **options)
 
 def generate_sprite(tag, **options):
@@ -195,13 +201,14 @@ def call_api(action, params, **options):
         else:
             param_list.append(("file", file))
     request = urllib2.Request(api_url + "?" + urllib.urlencode(param_list), datagen, headers)
+    request.add_header("User-Agent", cloudinary.USER_AGENT)
 
     code = 200
     try:
         response = urllib2.urlopen(request).read()
     except urllib2.HTTPError, e:
         if not e.code in [200, 400, 500]:
-            raise Exception("Server returned unexpected status code - %d - %s" % (e.code, e.read()))
+            raise Error("Server returned unexpected status code - %d - %s" % (e.code, e.read()))
         code = e.code
         response = e.read()
 
@@ -209,13 +216,13 @@ def call_api(action, params, **options):
         result = json.loads(response)
     except Exception, e:
         # Error is parsing json
-        raise Exception("Error parsing server response (%d) - %s. Got - %s", code, response, e)
+        raise Error("Error parsing server response (%d) - %s. Got - %s", code, response, e)
 
     if "error" in result:
         if return_error:
             result["error"]["http_code"] = response.code
         else:
-            raise Exception(result["error"]["message"])
+            raise Error(result["error"]["message"])
 
     return result
 
